// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com
// Apdo. 964-1250 Escaz, San Jos, Costa Rica
// dedicado a Jess y Mara...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 15 febrero 2011
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
//
// Facil de usar, tan simple como
// #include "STMC.inc"
// object       { STMC_Silla() }
// #macro STMC_Silla()
//      Macro para SillaTerrazaMesaCircular, genera
//      una version default del objeto
// El objeto tambien puede generarse con la siguiente macro
// #macro STMC_MacroSilla ( GruesoVarilla, GruesoAsiento, 
//                        TexturaMetal, TexturaTela )
//      GruesoVarilla   : Grueso de las varillas, default es 8*L.
//      GruesoAsiento   : Grueso del asiento, default es 29*L.
//      TexturaMetal    : texture { ... }, a aplicar a las varillas.
//      TexturaTetal    : texture { ... }, a aplicar al asiento,
//                              respaldo y brazos de la silla.
// DiametroVarilla      = 8*L
// GruesoAsiento        = 29*L 
// Alto                 = 722*L 
// AltoAsiento          = 323*L
// RadioSillaPlano      = 143*L
// ProfundidadTrasera   = 185*L (a partir de centro de Silla )
// ProfundidadDelantera = 150*L (a partir de centro de Silla )
// ProfundidadRespaldo  = 147*L (a partir de centro de Silla )
// TamanoMaximoFrontal  = 560*L
// El circulo del asiento directamente sobre (y) del origen.
// Las patas reposan en el plano XZ.  Frente hacia z-. 
// Variables generadas con cada llamado de la macro:
// STMC_AlturaAsiento   : Da la altura del asiento
// STMC_RadioAsiento    : Da el radio plano del asiento  
//
// Se declaran las siguientes variables textura "default"
// que no deberian modificarse
// STMC_TexturaMetal
// STMC_TexturaTela
// El archivo posee los siguientes modificadores
// #declare STMC_POV3_1                 = off;
//      Para activar modo de compatibilidad con POVRay 3.1.
//      en algunas versiones se activa automaticamente.
//      Deberia activarse antes del include      
// #declare STMC_TexturaMetalDefault    = texture { STMC_TexturaMetal }
//      Para cambiar la textura default a aplicar en la STMC_Silla()
// #declare STMC_TexturaTelaDefault     = texture { STMC_TexturaTela  }
//      Para cambiar la textura defaule de tela en STMC_Silla()
// #include "STMC.inc"  
// #include "textures.inc"
// #declare STMC_TexturaMetalDefault = texture       {
//      average
//      texture_map     {
//              [ 0.5 STMC_TexturaMetal ]
//              [ 0.5 RustyIron         ]
//      }
// }
// object               {
//   STMC_Silla()
// }
// sphere               {
//   0, 0.05
//   translate  ( STMC_AlturaAsiento+0.05 )*y      
//   pigment            { Red }
// }
//
// Aclaracion:
// Las macros STMC_Reorient_Trans y STMC_Axis_Rotate_Trans
// se transcribe casi identica a la original
// en "transforms.inc" Reorient_Trans y Axis_Rotate_Trans
// se copia por compatibilidad con POVRay 3.1.
// La macro STMC_VPerp_To_Vector
// se tomo de "math.inc" VPerp_To_Vector
// por compatibilidad con POVRay 3.1.
//
 
#include "colors.inc" 
#include "STMC_Aux.inc"

#if ( version < 3.2 )
  #ifndef( STMC_POV3_1 )
    #declare STMC_POV3_1        = on;
  #end
#else
  #ifndef( STMC_POV3_1 )
    #declare STMC_POV3_1        = off;
  #end
#end

#declare STMC_L         = 0.001;

#declare STMC_TexturaMetal      = texture       { 
    pigment       { White }
}

#ifndef ( STMC_TexturaMetalDefault )
  #declare STMC_TexturaMetalDefault     = texture       {
    STMC_TexturaMetal
  }
#end

#declare STMC_TexturaTela       = texture       {
  pigment {
      quilted  
      control0 0.5
      control1 0.8
      pigment_map { 
          [ 0.0 color Red    ]
          [ 0.3 color Orange ]
          [ 1.0 color Red    ]
        }
      turbulence 0.4 
      scale     0.02
      rotate    45
  }
  normal  {
      quilted  
      control0 0.5
      control1 0.8
      turbulence 0.4 
      scale     0.02
      rotate    45
  }
}

#ifndef ( STMC_TexturaTelaDefault )
  #declare STMC_TexturaTelaDefault      = texture       {
    STMC_TexturaTela
  }
#end

#macro STMC_GiroY ( MyPunto, LongitudArco )
  #local Radio          = sqrt( vdot( MyPunto, MyPunto ) );
  #local Angulo         = LongitudArco/Radio;
  < ( MyPunto.x*cos( Angulo )-MyPunto.z*sin( Angulo ) ),
    MyPunto.y,
    ( MyPunto.x*sin( Angulo )+MyPunto.z*cos( Angulo ) ) >
#end

  // Decorado en media S BanderaInicio false elimina inicio
#macro STMC_Decorado   ( Inicio, Fin, Lateral,
                        Aj1, Aj2, RadioI, BanderaInicio )
  #local PuntoL         = vdot( Lateral-Inicio, vnormalize( Fin-Inicio ) )*
                        vnormalize( Fin-Inicio )+Inicio;
  #local LateralE       = 2*PuntoL-Lateral;
  #local ControlExtra   = Fin+Aj1*( ( Lateral+2*PuntoL )/3-Fin );
  #local ControlUltimo  = ( Inicio+PuntoL )/2+Aj2*( PuntoL-Lateral );
  union                 {
    object              {
      STMC_SweepTriplePunto( PuntoL, ControlExtra, Lateral, RadioI, true )
    }
    object              {
      STMC_SweepTriplePunto( Lateral, Fin, LateralE, RadioI, false )
    }
    #if ( BanderaInicio )
      object              {
        STMC_SweepTriplePunto( LateralE, ControlUltimo, Inicio, RadioI, true )
      }
    #else
      sphere            {
        LateralE        , RadioI
      }
    #end
  }
#end

#macro STMC_MacroSilla ( GruesoVarilla, GruesoAsiento, 
                        TexturaMetal, TexturaTela )
  #local L                              = STMC_L;
  #local SeparacionPataTrasera          = 265*L;
  #local SeparacionPataDelantera        = 358*L;
  #local ProfundidadPataDelantera       = 343*L;
  #local RadioCircular                  = 143*L;
  #local AltoCircular                   = 286*L;
  #local AltoTotal                      = 714*L;
  #local GruesoPrincipal                = GruesoVarilla;
  #local GruesoAro                      = GruesoPrincipal;
  #local GruesoFino                     = 5.5/7*GruesoPrincipal;
  #local CorreccionBrazo                = 33*L;
  #local AnchoBrazo                     = 43*L;
  #local AltoBrazo                      = 429*L;
  #local PuntoSalidaBrazo               =
    < SeparacionPataTrasera/2+CorreccionBrazo, AltoBrazo,
    -CorreccionBrazo+RadioCircular >;
  #local CorreccionFinal                = 38*L;
  #local PuntoFinal                     =
    < 0, AltoTotal, CorreccionFinal+RadioCircular >;
  #local PuntoPiv3      =
                PuntoSalidaBrazo+0.5*( y+z )*( PuntoFinal-PuntoSalidaBrazo );
  #local SeparacionRespaldo             = 172*L;
  #local AltoRespaldo                   = 370*L;
  #local PataTrasera                    = union         {
    #local Angulo1      = radians( 45 );
    #local Cor1         = 50*L*x;
    #local P            =
      < cos( Angulo1 )*( RadioCircular+GruesoPrincipal ), AltoCircular,
        sin( Angulo1 )*( RadioCircular+GruesoPrincipal ) >;
    #local Q            = < SeparacionPataTrasera/2, 0, 0 >+RadioCircular*z;
    #local C            = ( P+Q )/2-Cor1;
    object              {
      STMC_SweepTriplePunto( P, C, Q, GruesoPrincipal/2, true )
    }
    #local P2           = STMC_GiroY( P, -RadioCircular/1.5 );
    #local Q2           = STMC_GiroY( Q, -GruesoPrincipal );
    #local C2           = STMC_GiroY( C, -RadioCircular/3.0 );
    object              {
      STMC_SweepTriplePunto( P2, C2, Q2, GruesoPrincipal/2, true )
    }
    object              {
      STMC_SweepTriplePunto( P, PuntoSalidaBrazo,
                        PuntoPiv3, GruesoPrincipal/2, false )
    }
    // Decorados
    #local AnchoDecorado        = SeparacionRespaldo/5;
    #local Punto1               = < +GruesoFino/2,
        -GruesoPrincipal/2-GruesoFino/2+AltoRespaldo-AnchoDecorado/2,
        +RadioCircular+0.6*CorreccionFinal >;
    #local Punto2               =
                Punto1+( AnchoDecorado/2 )*( 0.9*x-y );
    #local Punto3               =
                Punto1+( AnchoDecorado/2 )*( 4*0.9*x );
    object              {
      STMC_Decorado( Punto3, Punto1, Punto2, 1.5, 0.8, GruesoFino/2, false )
    }
    cylinder            {
      Punto2*<1,1,1>+AnchoDecorado*y,
      Punto2*<0,1,1>+AnchoDecorado*y+SeparacionRespaldo/2*x,
      GruesoFino/2
    }
    #local Punto4       = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Punto4, PuntoSalidaBrazo, P,
                        PuntoPiv3, 0.22 )
    #local Punto4       = Punto4-( GruesoPrincipal/2+GruesoFino/2 )*x;
    #local Punto5       = Punto4-( AnchoDecorado/2 )*( 0.7*x+y-0.7*z );
    #local Punto6       = Punto4-( AnchoDecorado/2 )*( 4*0.7*x-4*0.7*z );
    object              {
      STMC_Decorado( Punto6, Punto4, Punto5, 1.5, 0.8, GruesoFino/2, false )
    }
    cylinder            {
      Punto2*<0,1,1>+AnchoDecorado*y+SeparacionRespaldo/2*x,
      Punto4+( AnchoDecorado/2 )*( -0.7*x+y+0.7*z ),
      GruesoFino/2
    }
    sphere              {
      Punto2*<0,1,1>+AnchoDecorado*y+SeparacionRespaldo/2*x,
      GruesoFino/2
    }
    sphere              {
      Punto4+( AnchoDecorado/2 )*( -0.7*x+y+0.7*z ),
      GruesoFino/2
    }
    #local PuntoBordeA          = < SeparacionRespaldo/2,
                0.5*SeparacionRespaldo+AltoRespaldo,
                +RadioCircular+0.64*CorreccionFinal >;
    #local Punto7       = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Punto7, PuntoSalidaBrazo, P,
                        PuntoPiv3, 0.60 )
    #local Punto7       = Punto7-( GruesoPrincipal/2+GruesoFino/2 )*x;
    #local Punto8       = Punto7-( AnchoDecorado/2 )*( 0.7*x+y-0.7*z );
    object              {
      STMC_Decorado
        ( PuntoBordeA, Punto7, Punto8, 1.5, 1.0, GruesoFino/2, true  )
    }
    #local PuntoBordeB          = < SeparacionRespaldo/2,
                SeparacionRespaldo+AltoRespaldo,
                +RadioCircular+0.80*CorreccionFinal >;
    #local Punto9       = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Punto9, PuntoSalidaBrazo, P,
                        PuntoPiv3, 0.92 )
    #local Punto9       = Punto9-( GruesoPrincipal/2+GruesoFino/2 )*x;
    #local Punto10      = Punto9-( AnchoDecorado/2 )*( 0.65*x+y-0.65*z );
    object              {
      STMC_Decorado
        ( PuntoBordeB, Punto9, Punto10, 1.5, 1.0, GruesoFino/2, true  )
    }
    #local PuntoBordeC          = < AnchoDecorado/2,
                1.5*SeparacionRespaldo+AltoRespaldo,
                +RadioCircular+0.80*CorreccionFinal >;
    #local Punto11      =
         PuntoFinal-( GruesoPrincipal/2+GruesoFino/2 )*y
         +1.4*AnchoDecorado/2*x;
    #local Punto12      = Punto11+( AnchoDecorado/2 )*( x-0.9*y-0.2*z );
    object              {
      STMC_Decorado
        ( PuntoBordeC, Punto11, Punto12, 1.5, 1.0, GruesoFino/2, true  )
    }    
  }
  #local PataDelantera          = union         {
    #local Angulo1D     = radians( 67 );
    #local PD           =
      < cos( Angulo1D )*RadioCircular, AltoCircular,
        -sin( Angulo1D )*RadioCircular  >;
    #local QD           = < SeparacionPataDelantera/2, 0, -RadioCircular >;
    #local CD           = ( PD+QD )/2;
    #local AD           = ( QD+CD )/2*<0.90,1,0.90>;
    #local BD           = ( PD+CD )/2*<1.10,1,1.10>;
    object              {
      STMC_SweepTriplePunto( PD, BD, CD, GruesoPrincipal/2, true  )
    }
    object              {
      STMC_SweepTriplePunto( QD, AD, CD, GruesoPrincipal/2, false )
    }
    #local PD2          = STMC_GiroY( PD, RadioCircular/2 );
    #local QD2          = STMC_GiroY( QD, GruesoPrincipal  );
    #local CD2          = STMC_GiroY( CD, RadioCircular/4 );
    #local AD2          = ( QD2+CD2 )/2*<0.90,1,0.90>;
    #local BD2          = ( PD2+CD2 )/2*<1.10,1,1.10>;
    object              {
      STMC_SweepTriplePunto( PD2, BD2, CD2, GruesoPrincipal/2, true  )
    }
    object              {
      STMC_SweepTriplePunto( QD2, AD2, CD2, GruesoPrincipal/2, false )
    }
    #local Piv1         = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Piv1, BD, PD, CD, 0.4 )
    #local Piv2         = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Piv2, BD2, PD2, CD2, 0.4 )
    #local Piv3         = Piv2*<1,0,1>;
    #local Piv3         = < 0, Piv2.y, -1.00*sqrt( vdot( Piv3,Piv3 ) ) >;
    #local Piv4         = STMC_GiroY( Piv3, RadioCircular/6 );
    object              {
      STMC_SweepTriplePunto( Piv1, Piv4, Piv3, GruesoPrincipal/2, false )
    }
    #local Final        = ( Piv1+Piv2 )/2;
    STMC_InterpolacionTriplePunto( Piv3, BD, PD, CD, 0.2 )
    #local Piv4         = Piv3*<1,0,1>;
    #local Piv4         = < 0, Piv3.y, -sqrt( vdot( Piv4,Piv4 ) ) >;
    #local Piv4         = STMC_GiroY( Piv4, GruesoFino/2 );
    #local Piv5         = < RadioCircular*cos( radians( 85 ) ),
                               AltoCircular-GruesoPrincipal/2,
                                -RadioCircular*sin( radians( 85 ) )>;
    object              {
      STMC_Decorado( Piv3, Piv4, Piv5, 1.5, 0.8, GruesoFino/2, true )
    }
    #local Piv1         = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Piv1, BD, PD, CD, 0.7 )
    #local Piv2         = < 0, 0, 0 >;
    STMC_InterpolacionTriplePunto( Piv2, BD2, PD2, CD2, 0.7 )
    #local Inicio       = ( Piv1+Piv2 )/2;
    #local Lateral      = ( Inicio+6*Final )/7;
    #local Lateral      = STMC_GiroY( Lateral,
                0.20*RadioCircular-GruesoPrincipal/2-GruesoFino/2 );
    object              {
      STMC_Decorado( Inicio, Final, Lateral,
        1.5, 0.8, GruesoFino/2, true )
    }
    #local Final        = ( CD+CD2 )/2;
    #local Lateral      = ( Inicio+7*Final )/8;
    #local Lateral      = STMC_GiroY( Lateral,
                -( 0.15*RadioCircular-GruesoPrincipal/2-GruesoFino/2 ) );
    object              {
      STMC_Decorado( Inicio, Final, Lateral,
        1.5, 0.8, GruesoFino/2, true )
    }
  }
  #declare MangoBrazo   = union         {
    #local ExtensionX   = 50*L;
    #local CorreccionX  = 20*L;
    #local AnguloControl        = radians( 15 );
    #local Control1     = PuntoSalidaBrazo+ExtensionX*x;
    #local Control4     =
      < cos( AnguloControl )*RadioCircular, AltoCircular,
        -sin( AnguloControl )*RadioCircular  >;
    #local Control2     = Control1*<1,1,0>+Control4*<0,0,1>;
    #local Control3     = Control2*<1,0,1>+Control4*<0,1,0>;
    cylinder            {
      PuntoSalidaBrazo, Control1-CorreccionX*x, GruesoPrincipal/2
    }
    cylinder            {
      Control1-CorreccionX*z, Control2+CorreccionX*z, GruesoPrincipal/2
    }
    cylinder            {
      Control2-CorreccionX*y, Control3+CorreccionX*y, GruesoPrincipal/2
    }
    cylinder            {
      Control3-CorreccionX*x, Control4, GruesoPrincipal/2
    }
    #local CuartoTorus  = difference    {
      torus             {
        CorreccionX     , GruesoPrincipal/2
      }
      plane             {
        x               , 0
      }
      plane             {
        z               , 0
      }
    }
    object              {
      CuartoTorus
      rotate            -90*x
      rotate            90*y
      translate         Control2+( -y+z )*CorreccionX
    }
    object              {
      CuartoTorus
      translate         Control1+( -x-z )*CorreccionX
    }
    object              {
      CuartoTorus
      rotate            90*x
      translate         Control3+( -x+y )*CorreccionX
    }
    union               {
      #local FactorBrazo        = 0.75;
      #local Brazo1             = 0.8*< Control1.x, Control1.z >
                        +0.2*< Control2.x, Control2.z >;
      #local Brazo2             = 0.1*< Control1.x, Control1.z >
                        +0.9*< Control2.x, Control2.z >;
      prism             {
        Control1.y+GruesoPrincipal/2,
        Control1.y+GruesoPrincipal/2+FactorBrazo*GruesoAsiento
        5,
        Brazo1,
        Brazo2,
        Brazo2+<AnchoBrazo,0>,
        Brazo1+<AnchoBrazo,0>,
        Brazo1
      }
      #local Brazo1_D           =
        < Brazo1.x, Control1.y+GruesoPrincipal/2
                +FactorBrazo*GruesoAsiento/2, Brazo1.y >;
      #local Brazo2_D           =
        < Brazo2.x, Control2.y+GruesoPrincipal/2
                +FactorBrazo*GruesoAsiento/2, Brazo2.y >;
      cylinder          {
        Brazo1_D,
        Brazo2_D,
        FactorBrazo*GruesoAsiento/2
      }
      sphere            {
        Brazo2_D,
        FactorBrazo*GruesoAsiento/2
      }
      cylinder          {
        Brazo2_D,
        Brazo2_D+AnchoBrazo*x,
        FactorBrazo*GruesoAsiento/2
      }
      sphere            {
        Brazo2_D+AnchoBrazo*x,
        FactorBrazo*GruesoAsiento/2
      }
      cylinder          {
        Brazo2_D+AnchoBrazo*x,
        Brazo1_D+AnchoBrazo*x,
        FactorBrazo*GruesoAsiento/2
      }
      sphere            {
        Brazo1_D+AnchoBrazo*x,
        FactorBrazo*GruesoAsiento/2
      }
      cylinder          {
        Brazo1_D+AnchoBrazo*x,
        Brazo1_D,
        FactorBrazo*GruesoAsiento/2
      }
      sphere            {
        Brazo1_D,
        FactorBrazo*GruesoAsiento/2
      }
      texture           {
        TexturaTela
      }
    }
  }
  union                 {
    torus               {
      RadioCircular     , GruesoPrincipal/2
      translate         AltoCircular*y
    }
    // Asiento
    #local FactorAsiento        = 2;
    union               {
      cylinder          {
        ( AltoCircular+GruesoAro/2 )*y,
        ( AltoCircular+GruesoAro/2+GruesoAsiento )*y,
        RadioCircular
      }
      torus             {
        FactorAsiento*RadioCircular, GruesoAsiento/2
        scale             < 1/FactorAsiento, 1, 1/FactorAsiento >
        translate       ( AltoCircular+GruesoAro/2+GruesoAsiento/2 )*y
      }
      texture           {
        TexturaTela
      }
    }
    object              {
      PataTrasera
    }
    object              {
      PataTrasera
      scale             <-1,1,1>
    }
    object              {
      STMC_SweepTriplePunto( PuntoPiv3, PuntoFinal, PuntoPiv3*<-1,1,1>,
                GruesoPrincipal/2, true )
    }
    object              {
      PataDelantera
    }
    object              {
      PataDelantera
      scale             <-1,1,1>
    }
    union               {
      cylinder            {
        < SeparacionRespaldo/2, 0, 0 >,
        < -SeparacionRespaldo/2, 0, 0 >, GruesoPrincipal/2
        translate       0.6*CorreccionFinal*z
      }
      cylinder            {
        < SeparacionRespaldo/2, 0, 0.6*CorreccionFinal >,
        < SeparacionRespaldo/2, SeparacionRespaldo, 0.8*CorreccionFinal >,
                                                        GruesoPrincipal/2
      }
      cylinder            {
        < -SeparacionRespaldo/2, 0, 0.6*CorreccionFinal >,
        < -SeparacionRespaldo/2, SeparacionRespaldo, 0.8*CorreccionFinal >,
        GruesoPrincipal/2
      }
      sphere            {
        < SeparacionRespaldo/2, 0, 0.6*CorreccionFinal >,
        GruesoPrincipal/2
      }
      sphere            {
        < -SeparacionRespaldo/2, 0, 0.6*CorreccionFinal >,
        GruesoPrincipal/2
      }
      sphere            {
        < SeparacionRespaldo/2, SeparacionRespaldo, 0.8*CorreccionFinal >,
        GruesoPrincipal/2
      }
      sphere            {
        < -SeparacionRespaldo/2, SeparacionRespaldo, 0.8*CorreccionFinal >,
        GruesoPrincipal/2
      }
      difference        {
        torus             {
          SeparacionRespaldo/2    , GruesoPrincipal/2
          rotate          90*x
          translate     0.8*CorreccionFinal*z
        }
        plane           {
          y             , 0
        }
        translate       SeparacionRespaldo*y
      }
      union             {
        #local FactorRespaldo           = 0.5;
        #local PuntoAR                  =
        < -SeparacionRespaldo/2, SeparacionRespaldo,
                0.8*CorreccionFinal-GruesoPrincipal/2 >;
        #local PuntoBR                  =
        < +SeparacionRespaldo/2, SeparacionRespaldo,
                0.8*CorreccionFinal-GruesoPrincipal/2 >;
        difference      {
          union           {
            cylinder          {
              ( PuntoAR+PuntoBR )/2,
              ( PuntoAR+PuntoBR )/2-FactorRespaldo*GruesoAsiento*z,
              SeparacionRespaldo/2
            }
            torus           {
              SeparacionRespaldo/2,
              FactorRespaldo*GruesoAsiento/2
              rotate        90*x
              translate     ( PuntoAR+PuntoBR )/2
                        -FactorRespaldo*GruesoAsiento/2*z
            }
          }
          plane           {
            y,    +PuntoAR.y
          }
        }
        sphere          {
          PuntoAR-FactorRespaldo*GruesoAsiento/2*z,
          FactorRespaldo*GruesoAsiento/2
        }
        sphere          {
          PuntoBR-FactorRespaldo*GruesoAsiento/2*z,
          FactorRespaldo*GruesoAsiento/2
        }
        union           {
          #local AmpY           = 1.000;
          #local PuntoAR2        =
        < -SeparacionRespaldo/2, 0, -FactorRespaldo*GruesoAsiento/2 >;
          #local PuntoBR2        =
        < +SeparacionRespaldo/2, 0, -FactorRespaldo*GruesoAsiento/2 >;
          #local PuntoCR2        =
        < -SeparacionRespaldo/2, -AmpY*SeparacionRespaldo, PuntoAR2.z >;
          #local PuntoDR2        =
        < +SeparacionRespaldo/2, -AmpY*SeparacionRespaldo, PuntoAR2.z >;
          prism         {
            -AmpY*SeparacionRespaldo,
            0
            5,
            <-0.5*SeparacionRespaldo,0>,
            <+0.5*SeparacionRespaldo,0>,
            <+0.5*SeparacionRespaldo,-FactorRespaldo*GruesoAsiento >,
            <-0.5*SeparacionRespaldo,-FactorRespaldo*GruesoAsiento >,
            <-0.5*SeparacionRespaldo,0>
          }
          cylinder      {
            PuntoAR2, PuntoBR2, FactorRespaldo*GruesoAsiento/2
          }
          cylinder      {
            PuntoAR2, PuntoCR2, FactorRespaldo*GruesoAsiento/2
          }
          cylinder      {
            PuntoBR2, PuntoDR2, FactorRespaldo*GruesoAsiento/2
          }
          cylinder      {
            PuntoCR2, PuntoDR2, FactorRespaldo*GruesoAsiento/2
          }
          sphere        {
            PuntoCR2, FactorRespaldo*GruesoAsiento/2
          }
          sphere        {
            PuntoDR2, FactorRespaldo*GruesoAsiento/2
          }
          rotate        2.5*x
          translate     SeparacionRespaldo*y
                +( +0.8*CorreccionFinal-GruesoPrincipal/2 )*z

        }
        texture         {
          TexturaTela
        }
      }
      translate         AltoRespaldo*y+RadioCircular*z
    }
    object            {
      MangoBrazo
    }
    object            {
      MangoBrazo
      scale           <-1,1,1>
    }
    #declare STMC_AlturaAsiento         = 
                        GruesoPrincipal+GruesoAsiento+AltoCircular; 
    #declare STMC_RadioAsiento          = RadioCircular; 
    translate           GruesoPrincipal/2*y
    texture             {
      TexturaMetal
    }
  }
#end

#macro STMC_Silla()
  #local L                      = STMC_L;
  #local GruesoAro              = 8*L;
  #local GruesoAsiento          = 29*L;
  object        {  
    STMC_MacroSilla( GruesoAro, GruesoAsiento,
        STMC_TexturaMetalDefault, STMC_TexturaTelaDefault )
  }
#end
