// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 19 abril 2011
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
//
// La macro RCPS_Tulipan( Semilla, TotalHojas )
// genera un objeto con
// las siguientes caracteristicas
// Base de Tulipan en origen
// orientado hacia y+
// Alto Tulipan         : 80*L en y (aleatorio)
// Radio Tulipan        : 50*L (aleatorio)
// Largo Tallo          : 3*AltoTulipan aprox.
// Radio Tallo          : 1.5*L
// Final Tallo          : Aleatorio en RCPS_FinalTallo
//              El vector 3D se genera automaticamente con la macro
//              Nota: -RCPS_FinalTallo.y/3 = AltoTulipan aprox.
// Los parametros serian
//      Semilla         : Numero seed para aleatoriedad
//                        misma Semilla implica misma flor
//      TotalHojas      : Numero de hojas en el tallito
//                        a partir de 0
//
// La macro RCPS_Margarita( Semilla, TotalHojas )
// genera un objeto con
// las siguientes caracteristicas
// Base de Margarita en origen
// orientado hacia z- (petalos radiales cerca del plano xy)
// Alto Margarita       : aleatorio, forma planar
// Alto Centro          : 4*L
// Radio Margarita      : 35*L aprox
// Largo Tallo          : 350*L aprox inclinado 45 grados (y-z+).
// Radio Tallo          : 1.5*L
// Final Tallo          : Aleatorio en RCPS_FinalTallo
//              El vector 3D se genera automaticamente con la macro
// Los parametros serian
//      Semilla         : Numero seed para aleatoriedad
//                        misma Semilla implica misma flor
//      TotalHojas      : Numero de hojas en el tallito
//                        a partir de 0
//
// Los objetos tambien se pueden generar via una macro principal
// #macro   RCPS_FlorPlasticaColorVariado
//        ( Estilo, Semilla, TexturaPrincipal,
//              TexturaSecundaria, TexturaHoja, TexturaTallo, TotalHojas  )
//  Existen dos estilos predefinidos
//      Estilo                  : RCPS_EstiloTulipan o RCPS_EstiloMargarita
//      Semilla                 : Numero seed para aleatoriedad
//      TexturaPrincipal        : Se aplica a los petalos
//      TexturaSecundaria       : Se aplica a los estambres
//      TexturaHojas            : Se aplica a las hojas
//      TexturaTallo            : Se aplica al tallito
//      TotalHojas              : A partir de 0, controla el total
//              de hojas en el tallito
//
// Las siguientes variables no deberian modificarse
// RCPS_TexturaPrincipalTulipan
//      Define la textura utilizada en los petalos del Tulipan
// RCPS_TexturaSecundariaTulipan
//      Define la textura utilizada en los estambres del Tulipan
// RCPS_TexturaHojaTulipan
//      Define la textura utilizada en las hojas del Tulipan
// RCPS_TexturaTalloTulipan
//      Define la textura utilizada en el tallo del Tulipan
// RCPS_TexturaPrincipalMargarita
//      Define la textura utilizada en los petalos de la Margarita
// RCPS_TexturaSecundariaMargarita
//      Define la textura utilizada en los estambres de la Margarita
// RCPS_TexturaHojaMargarita
//      Define la textura utilizada en las hojas de la Margarita
// RCPS_TexturaTalloMargarita
//      Define la textura utilizada en el tallo de la Margarita
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)
// #declare RCPS_POV3_1         = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
// #declare RCPS_TexturaPrincipalTulipanDefault         = texture ...
//      Define la textura utilizada en los petalos del Tulipan
// #declare RCPS_TexturaSecundariaTulipanDefault        = texture ...
//      Define la textura utilizada en los estambres del Tulipan
// #declare RCPS_TexturaHojaTulipanDefault              = texture ...
//      Define la textura utilizada en las hojas del Tulipan
// #declare RCPS_TexturaTalloTulipanDefault             = texture ...
//      Define la textura utilizada en el tallo del Tulipan
// #declare RCPS_TexturaPrincipalMargaritaDefault            = texture ...
//      Define la textura utilizada en los petalos de la Margarita
// #declare RCPS_TexturaSecundariaMargaritaDefault           = texture ...
//      Define la textura utilizada en los estambres de la Margarita
// #declare RCPS_TexturaHojaMargaritaDefault                 = texture ...
//      Define la textura utilizada en las hojas de la Margarita
// #declare RCPS_TexturaTalloMargaritaDefault                = texture ...
//      Define la textura utilizada en el tallo de la Margarita
//
// Para colocarlo simplemente
// #include "RCPS.inc"
// object { RCPS_Margarita( 1232, 4 ) }
//
// Otro ejemplo con modificador
// #include "RCPS.inc"
// #declare RCPS_TexturaPrincipalMargaritaDefault    = texture       {
//   average
//   texture_map        {
//     [ 0.8 RCPS_TexturaPrincipalMargarita    ]
//     [ 0.2 RCPS_TexturaHojaMargarita         ]
//   }
// }
// object       { RCPS_Margarita( 1232, 4 ) }
//

#include "colors.inc"

#local   EjeMejorado            = false;
#local   OjoAbsoluto            = 256;
#local   VecesCentroAbsoluto    = 10;
#local   L                      = 0.001;
camera {
        location  <   0,  0, -( VecesCentroAbsoluto+1 )*OjoAbsoluto >*L
        direction z
        sky       y
        angle     38.74
//        look_at  <   0,  0, -VecesCentroAbsoluto*OjoAbsoluto >*L
}         
light_source    {
         < 500  , 500   , -3000 >*L
         White
}
light_source    {
         <-500  , 500   , -3000 >*L
         White
}
background      {
         Gray50
}    

#include "TMPS.inc"

object          {
  TMPS_Tulipan( 10250, 6.0 )
  rotate        -45*x
  translate     -0.05*x-2.40*z
}

object          {
  TMPS_Margarita( 50213, 5.0 )
  translate     +0.05*x-2.40*z+0.025*y
}

